import { createRoot } from "react-dom/client";
import App from "./App";
import "./index.css";

// Declare the global MIME type helper
declare global {
  interface Window {
    __fixMimeTypeIssues?: (path: string) => void;
  }
}

// For module MIME type compatibility in production
if (typeof window.__fixMimeTypeIssues === 'function') {
  try {
    // Try to load the main Vite entry point with our MIME type helper
    // This is a fallback for production environments where the MIME type might be wrong
    window.__fixMimeTypeIssues('/assets/index.js');
    
    // In production, we would generate the exact path with hash, e.g.:
    // window.__fixMimeTypeIssues('/assets/index-abcdef12.js');
    
    console.log("Production mode: using MIME type compatibility layer");
  } catch (err) {
    console.error("Failed to load module with compatibility layer:", err);
  }
}

// Always attempt to render the app directly
// In development this works normally
// In production, if the module loading fails due to MIME type, the helper above will kick in
createRoot(document.getElementById("root")!).render(<App />);
